==> hs-syb-0.3.7p0.tgz: lib/ghc/syb-0.3.7/register.sh <==
#!/bin/sh
echo 'name: syb
version: 0.3.7
id: syb-0.3.7-60af41a2377e93620710d393692aff24

license: BSD3
copyright:
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
package-url:
synopsis: Scrap Your Boilerplate
description: This package contains the generics system described in the
             /Scrap Your Boilerplate/ papers (see
             <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
             It defines the @Data@ class of types permitting folding and unfolding
             of constructor applications, instances of this class for primitive
             types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
pkgpath: devel/hs-syb
exposed: True
exposed-modules: Data.Generics Data.Generics.Basics
                 Data.Generics.Instances Data.Generics.Aliases Data.Generics.Schemes
                 Data.Generics.Text Data.Generics.Twins Data.Generics.Builders
                 Generics.SYB Generics.SYB.Basics Generics.SYB.Instances
                 Generics.SYB.Aliases Generics.SYB.Schemes Generics.SYB.Text
                 Generics.SYB.Twins Generics.SYB.Builders
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/syb-0.3.7
library-dirs: /usr/local/lib/ghc/syb-0.3.7
hs-libraries: HSsyb-0.3.7
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-syb-0.3.7/html/syb.haddock
haddock-html: /usr/local/share/doc/hs-syb-0.3.7/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-syb-0.4.0.tgz: lib/ghc/syb-0.4.0/register.sh <==
#!/bin/sh
echo 'name: syb
version: 0.4.0
id: syb-0.4.0-c48d52f3188b986ddaa9dd9ae40072f8

license: BSD3
copyright:
maintainer: generics@haskell.org
stability: provisional
homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
package-url:
synopsis: Scrap Your Boilerplate
description: This package contains the generics system described in the
             /Scrap Your Boilerplate/ papers (see
             <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
             It defines the @Data@ class of types permitting folding and unfolding
             of constructor applications, instances of this class for primitive
             types, and a variety of traversals.
category: Generics
author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
pkgpath: devel/hs-syb
exposed: True
exposed-modules: Data.Generics Data.Generics.Basics
                 Data.Generics.Instances Data.Generics.Aliases Data.Generics.Schemes
                 Data.Generics.Text Data.Generics.Twins Data.Generics.Builders
                 Generics.SYB Generics.SYB.Basics Generics.SYB.Instances
                 Generics.SYB.Aliases Generics.SYB.Schemes Generics.SYB.Text
                 Generics.SYB.Twins Generics.SYB.Builders
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/syb-0.4.0
library-dirs: /usr/local/lib/ghc/syb-0.4.0
hs-libraries: HSsyb-0.4.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-syb-0.4.0/html/syb.haddock
haddock-html: /usr/local/share/doc/hs-syb-0.4.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
